@@ -70,6 +70,8 @@ import com.openexchange.imap.cache.NamespaceFoldersCache;
 import com.openexchange.imap.cache.RootSubfolderCache;
 import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.services.Services;
+import com.openexchange.java.StringAllocator;
+import com.openexchange.java.Strings;
 import com.openexchange.log.Log;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.MailSessionCache;
@@ -89,6 +91,7 @@ import com.openexchange.spamhandler.SpamHandlerRegistry;
 import com.openexchange.tools.UnsynchronizedStringWriter;
 import com.sun.mail.imap.DefaultFolder;
 import com.sun.mail.imap.IMAPFolder;
+import com.sun.mail.imap.IMAPStore;
 
 /**
  * {@link IMAPDefaultFolderChecker} - The IMAP default folder checker.
@@ -109,8 +112,9 @@ public class IMAPDefaultFolderChecker {
 
     protected final Session session;
     protected final int accountId;
-    protected final AccessedIMAPStore imapStore;
+    protected final IMAPStore imapStore;
     protected final Context ctx;
+    protected final IMAPAccess imapAccess;
     protected final IMAPConfig imapConfig;
     protected boolean retry;
 
@@ -123,14 +127,15 @@ public class IMAPDefaultFolderChecker {
      * @param imapStore The (connected) IMAP store
      * @param imapConfig The IMAP configuration
      */
-    public IMAPDefaultFolderChecker(final int accountId, final Session session, final Context ctx, final AccessedIMAPStore imapStore, final IMAPConfig imapConfig) {
+    public IMAPDefaultFolderChecker(final int accountId, final Session session, final Context ctx, final IMAPStore imapStore, final IMAPAccess imapAccess) {
         super();
         retry = true;
         this.accountId = accountId;
         this.session = session;
         this.imapStore = imapStore;
         this.ctx = ctx;
-        this.imapConfig = imapConfig;
+        this.imapAccess = imapAccess;
+        imapConfig = imapAccess.getIMAPConfig();
     }
 
     /**
@@ -278,7 +283,7 @@ public class IMAPDefaultFolderChecker {
                         /*
                          * Get prefix for default folder names, NOT full names!
                          */
-                        String prefix = imapStore.getImapAccess().getFolderStorage().getDefaultFolderPrefix();
+                        String prefix = imapAccess.getFolderStorage().getDefaultFolderPrefix();
                         /*
                          * Check for mbox
                          */
@@ -448,12 +453,12 @@ public class IMAPDefaultFolderChecker {
             if (isEmpty(fullName)) {
                 if (isEmpty(name)) {
                     // Neither full name nor name
-                    setDefaultMailFolder(index, checkDefaultFolder(index, prefix, getFallbackName(index), sep, type, subscribe, false, modified), cache);
+                    setDefaultMailFolder(index, checkDefaultFolder(index, prefix, getFallbackName(index), sep, type, subscribe, false, prefix, modified), cache);
                 } else {
-                    setDefaultMailFolder(index, checkDefaultFolder(index, prefix, name, sep, type, subscribe, false, modified), cache);
+                    setDefaultMailFolder(index, checkDefaultFolder(index, prefix, name, sep, type, subscribe, false, prefix, modified), cache);
                 }
             } else {
-                setDefaultMailFolder(index, checkDefaultFolder(index, "", fullName, sep, type, subscribe, true, modified), cache);
+                setDefaultMailFolder(index, checkDefaultFolder(index, "", fullName, sep, type, subscribe, true, prefix, modified), cache);
             }
         } catch (final OXException e) {
             final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
@@ -469,7 +474,7 @@ public class IMAPDefaultFolderChecker {
             }
             setDefaultMailFolder(index, null, cache);
             e.setCategory(Category.CATEGORY_WARNING);
-            imapStore.getImapAccess().addWarnings(Collections.singleton(e));
+            imapAccess.addWarnings(Collections.singleton(e));
         } catch (final FolderClosedException e) {
             /*
              * Not possible to retry since connection is broken
@@ -500,7 +505,7 @@ public class IMAPDefaultFolderChecker {
             }
             setDefaultMailFolder(index, null, cache);
             final OXException warning = MimeMailException.handleMessagingException(e, imapConfig, session).setCategory(Category.CATEGORY_WARNING);
-            imapStore.getImapAccess().addWarnings(Collections.singleton(warning));
+            imapAccess.addWarnings(Collections.singleton(warning));
         }
         return null;
     }
@@ -640,14 +645,14 @@ public class IMAPDefaultFolderChecker {
     /**
      * Internally used by {@link IMAPDefaultFolderChecker}.
      */
-    protected String checkDefaultFolder(final int index, final String prefix, final String qualifiedName, final char sep, final int type, final int subscribe, final boolean isFullname, final AtomicBoolean modified) throws MessagingException, OXException {
+    protected String checkDefaultFolder(final int index, final String prefix, final String qualifiedName, final char sep, final int type, final int subscribe, final boolean isFullname, final String detectedPrefix, final AtomicBoolean modified) throws MessagingException, OXException {
         /*
          * Check default folder
          */
         final StringBuilder tmp = new StringBuilder(32);
         final long st = DEBUG ? System.currentTimeMillis() : 0L;
         final int prefixLen = prefix.length();
-        final String fullName = prefixLen == 0 ? qualifiedName : tmp.append(prefix).append(qualifiedName).toString();
+        final String fullName = prefixLen == 0 ? qualifiedName : new StringAllocator(prefix).append(qualifiedName).toString();
         {
             final ListLsubEntry entry =
                 modified.get() ? ListLsubCache.getActualLISTEntry(fullName, accountId, imapStore, session) : ListLsubCache.getCachedLISTEntry(
@@ -677,7 +682,6 @@ public class IMAPDefaultFolderChecker {
             }
         }
         IMAPFolder f = (IMAPFolder) imapStore.getFolder(fullName);
-        tmp.setLength(0);
         if (isFullname) {
             /*
              * OK, a full name was passed. Try to create obviously non-existing IMAP folder.
@@ -714,6 +718,21 @@ public class IMAPDefaultFolderChecker {
                             if (isOverQuotaException(e)) {
                                 throw e;
                             }
+                            // Check for possibly wrong namespace
+                            if (!Strings.isEmpty(detectedPrefix) && !fullName.startsWith(detectedPrefix)) {
+                                final String checkedFullName = checkDefaultFolder(index, "", detectedPrefix + fullName, sep, type, subscribe, isFullname, detectedPrefix, modified);
+                                // Invalidate mail account settings as obviously wrong
+                                final MailAccountStorageService mass = Services.optService(MailAccountStorageService.class);
+                                if (null != mass) {
+                                    try {
+                                        mass.clearFullNamesForMailAccount(accountId, session.getUserId(), session.getContextId());
+                                    } catch (final Exception x) {
+                                        LOG.warn("Failed to clear full names for mail account " + accountId, x);
+                                    }
+                                }
+                                return checkedFullName;
+                            }
+                            // Failed for any reason
                             throw e;
                         }
                     } else {
@@ -779,6 +798,11 @@ public class IMAPDefaultFolderChecker {
                     if (isOverQuotaException(e)) {
                         throw e;
                     }
+                    // Check for possibly wrong namespace
+                    if (!Strings.isEmpty(detectedPrefix) && !fullName.startsWith(detectedPrefix)) {
+                        return checkDefaultFolder(index, "", detectedPrefix + fullName, sep, type, subscribe, isFullname, detectedPrefix, modified);
+                    }
+                    // Failed for any reason
                     throw e;
                 }
             } else {
