@@ -65,7 +65,6 @@ import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.imap.cache.ListLsubCache;
 import com.openexchange.imap.cache.ListLsubEntry;
-import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.services.Services;
 import com.openexchange.mail.MailSessionCache;
 import com.openexchange.mail.mime.MimeMailException;
@@ -82,6 +81,7 @@ import com.openexchange.spamhandler.NoSpamHandler;
 import com.openexchange.spamhandler.SpamHandler;
 import com.openexchange.spamhandler.SpamHandlerRegistry;
 import com.sun.mail.imap.IMAPFolder;
+import com.sun.mail.imap.IMAPStore;
 
 /**
  * {@link SpecialUseDefaultFolderChecker} - The IMAP default folder checker.
@@ -103,8 +103,8 @@ public class SpecialUseDefaultFolderChecker extends IMAPDefaultFolderChecker {
      * @param imapStore The (connected) IMAP store
      * @param imapConfig The IMAP configuration
      */
-    public SpecialUseDefaultFolderChecker(final int accountId, final Session session, final Context ctx, final AccessedIMAPStore imapStore, final IMAPConfig imapConfig) {
-        super(accountId, session, ctx, imapStore, imapConfig);
+    public SpecialUseDefaultFolderChecker(final int accountId, final Session session, final Context ctx, final IMAPStore imapStore, final IMAPAccess imapAccess) {
+        super(accountId, session, ctx, imapStore, imapAccess);
     }
 
     @Override
@@ -238,7 +238,7 @@ public class SpecialUseDefaultFolderChecker extends IMAPDefaultFolderChecker {
      * Internally used by {@link SpecialUseDefaultFolderChecker}.
      */
     @Override
-    protected String checkDefaultFolder(final int index, final String prefix, final String qualifiedName, final char sep, final int type, final int subscribe, final boolean isFullname, final AtomicBoolean modified) throws MessagingException, OXException {
+    protected String checkDefaultFolder(final int index, final String prefix, final String qualifiedName, final char sep, final int type, final int subscribe, final boolean isFullname, final String detectedPrefix, final AtomicBoolean modified) throws MessagingException, OXException {
         /*
          * Check default folder
          */
