@@ -118,7 +118,7 @@ public final class FolderCache {
          * Check for folder
          */
         final MailFolder mailFolder = folderMap.get(fullName);
-        return (MailFolder) (null == mailFolder ? null : mailFolder.clone());
+        return null == mailFolder ? null : mailFolder.clone();
     }
 
     /**
@@ -227,6 +227,7 @@ public final class FolderCache {
                      */
                     return newFld;
                 }
+                newFld.setLiveAccess(false);
                 mailFolder = folderMap.putIfAbsent(fullName, newFld);
                 if (null == mailFolder) {
                     mailFolder = newFld;
@@ -234,11 +235,14 @@ public final class FolderCache {
             } catch (final MessagingException e) {
                 throw IMAPException.handleMessagingException(e, folderStorage.getImapConfig(), session, accountId, mapFor("fullName", fullName));
             }
+        } else {
+            // Fetched from cache
+            mailFolder.setLiveAccess(false);
         }
         /*
          * Return
          */
-        return (MailFolder) mailFolder.clone();
+        return (mailFolder.clone());
     }
 
     private static boolean isNotCacheable(final String fullName, final Session session, final int accountId, final IMAPStore imapStore) throws MessagingException {
@@ -326,11 +330,16 @@ public final class FolderCache {
         SessionMailCache.getInstance(session, accountId).get(entry);
         final FolderMap folderMap = entry.getValue();
         if (null != folderMap) {
-            synchronized (folderMap) {
-                final MailFolder mailFolder = folderMap.get(fullName);
-                if (null != mailFolder) {
-                    final int cur = mailFolder.getUnreadMessageCount();
-                    mailFolder.setUnreadMessageCount(cur > 0 ? cur - 1 : 0);
+            MailFolder mailFolder = folderMap.get(fullName);
+            if (null != mailFolder && mailFolder.getUnreadMessageCount() >= 0) {
+                synchronized (folderMap) {
+                    mailFolder = folderMap.get(fullName);
+                    if (null != mailFolder) {
+                        final int cur = mailFolder.getUnreadMessageCount();
+                        if (cur >= 0) {
+                            mailFolder.setUnreadMessageCount(cur > 0 ? cur - 1 : 0);
+                        }
+                    }
                 }
             }
         }
