@@ -174,6 +174,13 @@ public interface IIMAPProperties extends IMailProperties {
      */
     public int getMaxNumConnection();
 
+    /**
+     * Whether to allow folder caches.
+     *
+     * @return <code>true</code> if folder caches are allowed; otherwise <code>false</code>
+     */
+    public boolean allowFolderCaches();
+
     /**
      * Gets the map holding IMAP servers with new ACL Extension.
      *
