@@ -101,7 +101,7 @@ public final class ThreadSortUtil {
         if (null == threadResponse) {
             return Collections.emptyList();
         }
-        final char[] chars = threadResponse.toCharArray();
+        //final char[] chars = threadResponse.toCharArray();
         final List<MessageInfo> list = new LinkedList<MessageInfo>();
         int start = threadResponse.indexOf('{', 0);
         if (start < 0) {
@@ -228,15 +228,15 @@ public final class ThreadSortUtil {
      * @return An array of <code>javax.mail.Message</code> objects only filled with message's sequence number.
      */
     public static ExtendedMimeMessage[] getMessagesFromThreadResponse(final String folderFullname, final char separator, final String threadResponse) {
-        final char[] chars = threadResponse.toCharArray();
         final List<ExtendedMimeMessage> tmp = new ArrayList<ExtendedMimeMessage>();
         final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(8);
+        final int length = threadResponse.length();
         int i = 0;
-        while (i < chars.length) {
-            char c = chars[i++];
+        while (i < length) {
+            char c = threadResponse.charAt(i++);
             while (Character.isDigit(c)) {
                 sb.append(c);
-                c = chars[i++];
+                c = threadResponse.charAt(i++);
             }
             if (sb.length() > 0) {
                 tmp.add(new ExtendedMimeMessage(folderFullname, separator, Integer.parseInt(sb.toString())));
